#
# spec file for package nautilus-terminal
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nautilus-terminal
Version:        4.0.6
Release:        bp156.2.1
Summary:        A terminal embedded in Nautilus, the GNOME's file browser
License:        GPL-3.0-only
URL:            https://github.com/flozz/nautilus-terminal
Source:         https://files.pythonhosted.org/packages/source/n/nautilus-terminal/nautilus_terminal-%{version}.tar.gz
# PATCH-FIX-OPENSUSE do-not-install-compiled-schemas.patch -- On SUSE we must not installed the pre compiled schemas but the sources
Patch0:         do-not-install-compiled-schemas.patch
BuildRequires:  fdupes
BuildRequires:  python-nautilus-common-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3-psutil >= 5.6.6
BuildRequires:  python3-setuptools
BuildRequires:  pkgconfig(glib-2.0)
Requires:       nautilus
Requires:       python3-psutil >= 5.6.6
BuildArch:      noarch

%description
Nautilus Terminal is an integrated terminal for the Nautilus file browser.

%prep
%autosetup -p1 -n nautilus_terminal-%{version}
# See README
rm -v nautilus_terminal/not_packaged.py

%build
export SKIP_SCHEMA_COMPILE=1
%python3_build

%install
export SKIP_SCHEMA_COMPILE=1
%python3_install
%fdupes %{buildroot}%{python3_sitelib}

%files
%license COPYING
%doc README.rst
%{_bindir}/%{name}
%{python3_sitelib}/nautilus_terminal*
%{_datadir}/glib-2.0/schemas/org.flozz.nautilus-terminal.gschema.xml
%{_datadir}/nautilus-python/extensions/nautilus_terminal_extension.py

%changelog
* Thu Sep 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.6:
  + README: Fix reStructuredText syntax
- Changes from version 4.0.5:
  + Update supported Python versions
  + Allow detection of nautilus-terminal from the shell
* Fri Apr 22 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update version 4.0.4
  + Disable terminal audible bell
  + Fix a typo in the GSettings schema
* Thu Jul  1 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.0.2
  + Support Nautilus 40
  + Adds an "About" window
  + Adds a context menu to copy/paste, run dconf-editor and
    display the "About" window
  + Adds a CLI to check, install, uninstall, print debug, etc
  + Fixes Nautilus Terminal stealing the focus in new Nautilus windows
  + Adds an option to clear the terminal after each navigation
- Add do-not-install-compiled-schemas.patch
  + Do not install the precompiled schemas but the sources only
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.5
  + nautilus-terminal was completly rewritten in python (> 3.6)
  + Embed a Terminal in each Nautilus tab / window
  + Follows the navigation: if you navigate in Nautilus,
    the cd command is automatically executed in the terminal
  + Can be displayed / hidden using the F4 key
  + Configurable: font, background and text color, terminal
    position (displayed at top or at bottom of the windows)
  + Support for copy / paste through contextual menu and
    Ctrl+Shift+C / Ctrl+Shift+V
  + Supports drag & drop of file on the terminal
- Dropped outdated  nautilus-terminal-vte2.91.patch
- Modified build requirements:
  + Removed: gobject-introspection and vte-devel
  + Added:
  - python3-psutil for both, buildtime and runtime
  - python3-setuptools
  - Use fdupes and python-rpm-macros
  - pkgconfig(glib-2.0) for directory ownership
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Dec  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace python-nautilus with python-nautilus-common-devel
  BuildRequires.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Oct 12 2014 dimstar@opensuse.org
- Add nautilus-terminal-vte2.91.patch: Fix usage with Vte 2.91.
- Add vte-devel BuildRequires: needed in order to be able to detect
  if we need to apply the patch during build. If vte-2.91.pc exist,
  we apply the patch and make the resulting package depend on
  Vte 2.91.
* Mon Mar  4 2013 dimstar@opensuse.org
- Fix dependencies (bnc#807207):
  + Add gobject-introspection BuildRequires: Needed for the
    automatic typelib()-Requires generator.
  + Drop python-nautilus and python-gobject Requires: they are no
    longer needed, as nautilus-terminal was ported to pygobject.
* Wed Jan 18 2012 vuntz@opensuse.org
- Update to version 1.0:
  + Implement about dialog.
  + Add accelerators for copy/paste.
  + Implement drag and drop.
  + Bug fixes.
- Drop nautilus-terminal-gi-gobject.patch: fixed upstream.
* Wed Sep 28 2011 vuntz@opensuse.org
- Update to a bzr checkout of the GNOME 3 port (revision 9 of the
  1.x branch):
  + Rewrite for GNOME 3 technologies.
- Add nautilus-terminal-gi-gobject.patch: finish port to pygobject
  3.0, which has some differences with pygobject 2.x.
- Add python-gobject Requires as introspection-based bindings are
  now used.
- Drop python-vte Requires since we don't want the
  non-introspection-based bindings.
- Add python-xdg Recommends: this is an optional dependency, to
  find the configuration file for this extension.
- Mark package as noarch.
- Add have_lang macro, and make all the lang subpackage handling
  depend on its value. Set it to 0 for now, since there is no
  translation in the new branch.
* Thu Oct 28 2010 prusnak@opensuse.org
- Updated to version 0.7:
  + Fixes the "Terminal on desktop" bug
  + The terminal is now resizable with mouse (instead of buttons)
  + Updated translations.
- Changes from version 0.6:
  + Add optional scrollbar
  + Nautilus Terminal is now enabled for non-local folders (but
    with the path set on the home folder).
  + The install script now check the dependencies
  + The "terminal on desktop" bug is fixed (lp#642222)
  + Updated translations.
- Changes from version 0.5:
  + Fixes the refresh issue when the terminal is resized
  + Nautilus Terminal is again available in /media.
  + Nautilus Terminal Now support the drag & drop of file.
  + Updated translations.
- Changes from version 0.4:
  + Fixes a lot of bug and add some improvement (restart the shell
    after an "exit" command, Ctrl+Shift+T now toggle Show/Hide).
  + Updated translations.
* Mon Sep 13 2010 sbrabec@suse.cz
- New package, version 0.3.
